========
OpyenXes
========


.. image:: https://img.shields.io/pypi/v/opyenxes.svg
        :target: https://pypi.python.org/pypi/opyenxes

.. image:: https://img.shields.io/travis/wailamjonathanlee/opyenxes.svg
        :target: https://travis-ci.org/opyenxes/OpyenXes

.. image:: https://readthedocs.org/projects/opyenxes/badge/?version=latest
        :target: https://opyenxes.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/opyenxes/OpyenXes/shield.svg
     :target: https://pyup.io/repos/github/opyenxes/OpyenXes/
     :alt: Updates


A python implementation of the XES standard based on the Java implementation OpenXes.


* Free software: GNU General Public License v3
* Documentation: https://opyenxes.readthedocs.io.


Features
--------

* Complete replicate of the Java implementation OpenXes.

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

